#
# spec file for package rosegarden
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           rosegarden
Version:        14.02
Release:        0
License:        GPL-2.0+
Summary:        Midi, Audio And Notation Editor
Url:            http://www.rosegardenmusic.com/
Group:          Productivity/Multimedia/Sound/Midi
# http://sourceforge.net/projects/rosegarden/files/ This source url prevent me from checking out the tarball.
Source0:        %{name}/%{version}/%{name}-%{version}.tar.bz2
Source1:        %{name}.xpm
Source2:        %{name}.1
# This patch fixes the file search paths for examples, templates and midi driver libraries.
Patch1:         rosegarden-10.10-filepaths.patch
BuildRequires:  alsa-devel
BuildRequires:  automake
BuildRequires:  dssi-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa-devel
BuildRequires:  libjack-devel
BuildRequires:  liblo-devel
BuildRequires:  liblrdf-devel
BuildRequires:  libqt4-devel >= 4.6.3
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  lirc-devel
BuildRequires:  pkg-config
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-util-devel
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       dssi
Requires:       ladspa
Provides:       rosegarden-qt4 = %{version}
Provides:       rosegarden4 = %{version}
Obsoletes:      rosegarden-qt4 < %{version}
Obsoletes:      rosegarden4 < %{version}
Icon:           rosegarden.xpm
%if 0%{?suse_version} > 1120
Requires:       lilypond
%else
Recommends:     lilypond
%endif
Requires:       jack
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Rosegarden is a well-rounded audio and MIDI sequencer,
score editor, and general-purpose music composition and
editing environment. Rosegarden is an easy-to-learn,
attractive application that runs on Linux, ideal for
composers, musicians, music students, and small studio or
home recording environments.
This is a complete rewrite of the old 1.7.x series of
rosegarden and has many new features and enhancements.
See the changelog for details.

# TODO The current desktop menu category (kde4 at least) is Multimedia > Audio Player and not appropriate.

%prep
%setup -q
%patch1
# When we build svn we need to execute bootstrap.sh it doesn't harm the release build either.
sh bootstrap.sh

%build
export DEBUG_LADSPA
export QTDIR=/usr/
export CFLAGS="%{optflags} -fno-strict-aliasing -ggdb"
export CXXFLAGS="$CFLAGS"
# -fmessage-length=0 -O2 -fno-strict-aliasing -Wall -D_FORTIFY_SOURCE=2 -fstack-protector -funwind-tables -fasynchronous-unwind-tables
%configure --enable-debug --localedir=%{_datadir}/%{name}/locale/
make %{?_smp_mflags}
# This translation handling make section is possibly only necessary when building svn
make ts
make ts-noobsolete
make locale

%install
mkdir -p %{buildroot}%{_datadir}/%{name}/scripts
cp -p scripts/* %{buildroot}%{_datadir}/%{name}/scripts/
cp -r data/* %{buildroot}%{_datadir}/%{name}/

%make_install
rm -rf %{buildroot}%{_datadir}/%{name}/desktop
rm -rf %{buildroot}%{_datadir}/%{name}/mime
rm -f %{buildroot}%{_datadir}/%{name}/*.cpp
rm -f %{buildroot}%{_datadir}/%{name}/*.o
chmod 755 %{buildroot}%{_datadir}/%{name}/scripts/*
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/lircrc.rosegarden
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/README
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/color-list
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/simple-makefile

install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/pixmaps/%{name}.xpm"
%suse_update_desktop_file %{buildroot}/%{_datadir}/applications/%{name}.desktop
#This is a man page made by help2man to satisfy factories hunger for one /usr/bin/ one man page.
mkdir -p %{buildroot}%{_mandir}/man1
install -D -m 0644 "%{SOURCE2}" "%{buildroot}%{_mandir}/man1/"
%fdupes -s %{buildroot}%{_datadir}

%post
/usr/bin/update-mime-database "%{_datadir}/mime" >/dev/null

%postun
/usr/bin/update-mime-database "%{_datadir}/mime" >/dev/null

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README
%dir %{_datadir}/appdata
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/autoload
%dir %{_datadir}/%{name}/chords
%dir %{_datadir}/%{name}/examples
%dir %{_datadir}/%{name}/fonts
%dir %{_datadir}/%{name}/library
%dir %{_datadir}/%{name}/locale
%dir %{_datadir}/%{name}/profile
%dir %{_datadir}/%{name}/scripts
%dir %{_datadir}/%{name}/styles
%dir %{_datadir}/%{name}/templates
%dir %{_datadir}/%{name}/templates
%{_datadir}/icons/hicolor/*
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_mandir}/man1/*
%{_datadir}/%{name}/*
%{_datadir}/%{name}/presets/*
%{_datadir}/%{name}/pixmaps/*
%{_datadir}/%{name}/autoload/*
%{_datadir}/%{name}/chords/*
%{_datadir}/%{name}/examples/*
%{_datadir}/%{name}/fonts/*
%{_datadir}/%{name}/library/*
%{_datadir}/%{name}/locale/*
%{_datadir}/%{name}/profile/*
%{_datadir}/%{name}/scripts/*
%{_datadir}/%{name}/styles/*
%{_datadir}/%{name}/templates/*
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/appdata/rosegarden.appdata.xml

%changelog
